
# Type: gene to gene association_subject




URI: [biolink:gene_to_gene_association_subject](https://w3id.org/biolink/vocab/gene_to_gene_association_subject)


## Domain and Range

[GeneToGeneAssociation](GeneToGeneAssociation.md) ->  <sub>REQ</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [GeneToGeneAssociation](GeneToGeneAssociation.md)
 * [GeneToGeneHomologyAssociation](GeneToGeneHomologyAssociation.md)
 * [PairwiseGeneToGeneInteraction](PairwiseGeneToGeneInteraction.md)
